package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,`"``!````\!<``#0```!DI@``!Q``<#0`(``+
M`"@`(``?``8````T````-````#0```!@`0``8`$```4````$`````P```)0!
M``"4`0``E`$```T````-````!`````$````#``!PR`$``,@!``#(`0``&```
M`!@````$````"````````'#@`0``X`$``.`!```8````&`````0````$````
M`0````````````````````2>```$G@``!0```````0`!````])\``/2?`0#T
MGP$`[`$``!P2```&```````!``(````<`@``'`(``!P"``!0`0``4`$```0`
M```$````!````*0!``"D`0``I`$``"`````@````!`````0````$````^`$`
M`/@!``#X`0``)````"0````$````!````%+E=&3TGP``])\!`/2?`0`,````
M#`````0````!``````````````````````````````````````````0````O
M;&EB+VQD+G-O+C$`````!````!`````!````1TY5```````#`````@``````
M```````````@`@$!``4`````````````````````]@$`L@``````````````
M```````P(`(`!````!0````#````1TY5`)-)P57GARB3T8!)ZQ)V?#CWGH4@
M`0```$($```!````4@0```$```!=!````0```&<$```!````B00```$```"L
M!````0```+0$```,````I!0```T```"07```&0```/2?`0`;````!````!H`
M``#XGP$`'`````0````$````;`,```4```"0#0``!@```+`&```*````8`4`
M``L````0````-0``<(2=`0`5``````````,```!`H`$`$0```'P4```2````
M*````!,````(`````0``<`$````%``!P`@````8``'``````"@``<!P````1
M``!P;@```!(``'`?````$P``<",````8`````````/O__V\!```(_O__;\P3
M``#___]O`P```/#__V_P$@``````````````````````````````````````
M````````````````````````````80```&X````````````````````K````
M```````````S`````````#X````H````4`````````!*````40````X`````
M````60```!H````#````+0````D````1````/P```#```````````````%H`
M```5````)P``````````````(@```!T```!`````,0`````````6````(0``
M```````W`````````#4`````````20```!0````2````)0````````!K````
M&P````````!(````5P``````````````&````$L````[````1P``````````
M````8@````````!4`````````"```````````````&4````F````*0```"X`
M``!&````*@```````````````@````L```!"````:````!P````0````-@``
M```````C````'P``````````````$P```!<`````````00```!X```!$````
M)````#(````\`````````````````````````````````````````&<`````
M``````````````!I````````````````````4P```&8````*````#0``````
M````````10````0````````````````````9`````````&````!<````````
M````````````7P```#@````]`````````#0```!-````+P``````````````
M+```````````````80```&T`````````4@`````````Z````0P```$P`````
M````.0```%4``````````````&0```!/``````````````````````````\`
M````````"```````````````8P````P```!.`````````&H`````````70``
M````````````6P````````````````````````!6````6```````````````
M`````````````````````%X```!L```````````````%````````````````
M````!P`````````````````````````&````````````````````````````
M`````````````````````````````*04`````````P`-`"P```"D6```"```
M`!(`#@#N!```_#<``!@````2``X``0````$`````````$P#Q_PX%````H`$`
M`````"$`%@"B!``````````````1````4`(``$!```!4````$@`.`"($``#\
M5@``T````!(`#@#0!```X*$!```````0`!D`-@```)!<````````$@`0`/\$
M``#D.@``+````!(`#@!E`P``$#L``(`!```2``X`-P,``)Q"```L#P``$@`.
M``P%````H`$``````!$`%@"3!```P%P```0````1`!$`R00```"@`0``````
M$``6`.X!``#H-@``%`$``!(`#@`2````,*`!```````1`!<`'`````!8``"D
M````$@`.`,\#```@H`$`!````!$`%@#I!```$+(!```````0`!H`X`(``)`\
M`````P``$@`.`-<$``#@H0$``````!``&@"Q`0``##8``%0````2``X`20``
M`.`4```$`P``$@`.`!D%```P(`(``````!,`\?\B!0``\!<````````2``X`
MEP(``!0X``#0`@``$@`.`#X"``"40```"`(``!(`#@"D`@``D#\``+`````2
M``X`P@0``.`4````````$``.`.,$``#@H0$``````!``&@"S`0``I!0`````
M```2``T`R@$``,A1```T!0``$@`.`!D!``!P7````````!(```#X````8%P`
M```````2````"@$``%!<````````$@```-,"``!`7````````!(```!7`0``
M,%P````````2````.`$``"!<````````$@```"<!```07````````!(```"D
M!``````````````1````V0````!<````````$@```'D``````````````"``
M``!X`@``\%L````````2``````$``.!;````````$@```!D$``#06P``````
M`!(```!Y`0``P%L````````2````H@``````````````(````),#````````
M`````!(```#]`@``L%L````````2````"P(``*!;````````$@```&(!``"0
M6P```````!(```"Y`0``@%L````````2````V0,``'!;````````$@```"("
M``!@6P```````!(```!9`P``4%L````````2````_`,``$!;````````$@``
M`'(!```P6P```````!(```"&`@``(%L````````2````@`,`````````````
M$@```!D"```06P```````!(```!K`@```%L````````2````V0(``/!:````
M````$@```*8!``#@6@```````!(```!$`P``T%H````````2````'0,``,!:
M````````$@```+("``"P6@```````!(````\````H%H````````2````X0``
M`)!:````````$@```'$#``"`6@```````!(````$`@``<%H````````2````
M+@0`````````````$0```#T$``!@6@```````!(```!.```````````````B
M````Q@(``%!:````````$@```.T"``!`6@```````!(```#(`P``,%H`````
M```2````Z````"!:````````$@```+P#```06@```````!(```#@`0```%H`
M```````2````N0(``/!9````````$@```'<$``#@60```````!(```"Q`P``
MT%D````````2````"P,``,!9````````$@```(@!``"P60```````!(```!I
M`0``H%D````````2````I`,`````````````$0```.0#``"060```````!(`
M```Q`0``@%D````````2````3`$`````````````$0```#`"``!P60``````
M`!(```#(````8%D````````2````\@,``%!9````````$@````H$``!`60``
M`````!(````3`0``,%D````````2````E@$`````````````$@```"D#```@
M60```````!(```"V```````````````1````YP$``!!9````````$@```/<#
M````60```````!(```#P````\%@````````2````<0(`````````````$0``
M`&("``#@6````````!(```!=```````````````@````P0(``-!8````````
M$@```),``````````````"(````2`@``P%@````````2````-P(``+!8````
M````$@````!?1%E.04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!?7VQI8F-?8W-U
M7VEN:70`7U]L:6)C7V-S=5]F:6YI`%]?;&EB8U]S=&%R=%]M86EN`%]?9VUO
M;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%]?8WAA7V9I;F%L:7IE`%]*=E]296=I<W1E
M<D-L87-S97,`7U]S=&%C:U]C:&M?9W5A<F0`7U]S=&%C:U]C:&M?9F%I;`!S
M=')N8VUP`'-T<FQE;@!R96%L;&]C`&UE;6UO=F4`;W!E;F1I<@!R96%D9&ER
M-C0`8VQO<V5D:7(`<FUD:7(`7U]S<')I;G1F7V-H:P!?7WAS=&%T-C0`=6YL
M:6YK`'!T:')E861?9V5T<W!E8VEF:6,`4$Q?=&AR7VME>0!?7VQX<W1A=#8T
M`&%C8V5S<P!R96%D;&EN:P!M96UC:'(`4&5R;%]S=E]S971P=FX`4&5R;%]S
M=E]S971P=@!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!X<U]I;FET`%!E
M<FQ?;F5W6%-?9FQA9W,`6%-?26YT97)N86QS7U!!4E]"3T]4`&=E='!I9`!M
M96UC<'D`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'-T<F-H<@!S=')T;VL`<W1R
M8VUP`%]?<W1R9'5P`%]?<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!P87)?
M<V5T=7!?;&EB<&%T:`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!M:V1I
M<@!S=&1E<G(`7U]F<')I;G1F7V-H:P!?7V5R<FYO7VQO8V%T:6]N`'!A<E]F
M:6YD<')O9P!P87)?96YV7V-L96%N`&]P96XV-`!L<V5E:S8T`')E860`7U]M
M96UC<'E?8VAK`&-L;W-E`&UE;7-E=`!P87)?:6YI=%]E;G8`4&5R;%]G=E]F
M971C:'!V`%!E<FQ?879?9F5T8V@`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]G
M971?<W8`4&5R;%]A=E]S:&EF=`!P87)?;6MT;7!D:7(`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`4&5R;%]M9U]S970`<&%R7V1I<FYA;64`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?
M=6YD=6UP`'!E<FQ?86QL;V,`4&5R;%]S869E<WES;6%L;&]C`&UY7W!A<E]P
M;`!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES
M7W1E<FT`<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`<&%R7V-L96%N=7``4$Q?
M;65M;W)Y7W=R87``97AI=`!L:6)P97)L+G-O+C4N,C0`;&EB9&PN<V\N,@!L
M:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`%]?<F5G:7-T97)?871F;W)K`&QI
M8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7V5N=FER;VX`;&0N<V\N,0!L:6)C
M<GEP="YS;RXQ`%]F=&5X=`!?9F1A=&$`7V5D871A`%]?8G-S7W-T87)T`%]F
M8G-S`%]E;F0`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]D871A
M7W-T87)T`%]G<%]D:7-P`%]?<W1A<G0`1TQ)0D-?,BXT`$=,24)#7S(N,@!'
M3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(```````$``0`!``$`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$``0`!``D``@`"``0``P`$``,``@`"````"0`#````````````
M```"``(```````D```````(`!`````(``@`"``````````@``@`"`````@``
M``(````)`````@`"`````@`(``<``````````@```````@````(`!@``````
M`@``````!0`"``(``@`"``(````$``,``@`"``$``0"L!```$````"`````4
M:6D-```%`"H%`````````0`"`&<$```0````,````!)I:0T```@`-`4``!``
M```0:6D-```$`#X%`````````0`%`(D$```0`````````'09:0D```D`2`4`
M`!````!R&6D)```'`%0%```0````%&EI#0``!@`J!0``$````!)I:0T```,`
M-`4``!`````0:6D-```"`#X%``````````````````#TGP$``P```/B?`0`#
M````(*`!``,```#<H0$``P````(`'#R,"YPG(>"9`^#_O2<0`+RO'`"_KR"!
M@H\$`$`0`````""!F8\)^"`#`````!P`OX\(`.`#(`"])P(`'#Q0"YPG(>"9
M`ZC_O2<0@9F//`"PKQ@`O*]4`+^O4`"UKTP`M*](`+.O1`"RKT``L:^`@9"/
M+`"EKRP`I2<H`*:O*`"F)U@`I*]8`*0G```"CC0`HJ\)^"`#`````!@`O(_H
M@(:/6("9C[R`A(^?$!$$)2C``!@`O(]4@8*/``!"D&H`0!!$@9F/8(&1CY2`
MF8\)^"`#```DCA@`O(_F`T.0```DCI2`F8\"`&,T"?@@`^8#0Z``0`,\6`"D
MC^8#19`8`+R/!0"$)`$`I30K&(,`=0!@$.8#1:`T@9F/"?@@`X`@!``L`*6/
M&`"\CU@`IH\``*.,7("$CRB`B(\``$.L)("#CP``AXP"`,0H]+$"K4!@8R0(
M`$>L!``')`0`0ZPD@(./1&!C)`P`0ZPH@(./"@"`%/BQ9ZR`0`8`!`"C)!``
M1"0A0*@```!EC`0`A"0$`&,D_/\#%?S_A:PH@)&/@!@&`"2`A8\E.$``(1A#
M`-"`F8\#`,8D$`"@KP"R(HY@-J4D#`!@K"0`HJ\)^"`#)2!``!@`O(\U`$`0
M)9A``%B!F8\P`+0G"?@@`P"R)(XE*(`"&`"\CR2`DH\D@(2/U"Q2)B7(0`*)
M!1$$B%V$)"T`0!`8`+R/;(&9CPGX(`,`LB2.&`"\C]R`F8\)^"`#`````"40
M8`(T`*2/```#CCD`@Q08`+R/5`"_CU``M8],`+2/2`"SCT0`LH]``+&//`"P
MCP@`X`-8`+TG"?@@`P`````8`+R/*("#CRT`0!``LF*L<(&9CV"!D8\)^"`#
M)2!``!@`O(^4@)F/"?@@`P``)(X8`+R/B/\`$%4&0*"P@)F/"?@@`P"R)(X8
M`+R/Q_\`$"680``H@)6/_+&DC@H`@!!@@)F/WP\1!`````#-_P`0&`"\CR2`
MA(\8@86/_("9CPGX(`,D7X0D)("$CR4H@`(ER$`"2041!"1=A"08`+R/)2!`
M`+__0!#\L:*N[?\`$&"`F8]H@9F/"?@@`P`````<@9F/"?@@`P$`!"0`````
M```````````E`.`#`0`1!``````"`!P\-`B<)R'@GP,E^```&("$CP``I8\$
M`*8G^/\!)"3HH0/@_[TG'("'CR"`B(\0`*BO%`"BKQ@`O:\(@9F/"?@@`P``
M``#__P`0```````````"`!P\X`><)R'@F0,H@(2/9(""CS2@A"0#`$(D(Q!$
M``<`0BP%`$`4F(&9CP,`(!,`````"``@`P`````(`.`#``````(`'#R<!YPG
M(>"9`RB`A(]D@(6/-*"$)",HI`"#*`4`PA<%`"$H10!#*`4`!0"@$*2`F8\#
M`"`3``````@`(`,`````"`#@`P`````"`!P\4`><)R'@F0/@_[TG&`"PKRB`
MD(\0`+RO'`"_K^"A`I(-`$`4H(&"CP4`0!!H@(*/H(&9CPGX(`,``$2,$`"\
MCR2`F8]0&#DGR/\1!``````!``(DX*$"HAP`OX\8`+"/"`#@`R``O2<"`!P\
MY`:<)R'@F0,H@(*/X/^])_R?1"00`+RO'`"_KP``@HP&`$`4N("9CR2`F8\<
M`+^/E!@Y)\/_`!`@`+TG^O\@$P`````)^"`#`````/;_`!`0`+R/````````
M`````````@`</(`&G"<AX)D#4/V])X"!BH\X`(@D&`"B)Q``O*]X`(TDK`*_
MK_\`##RH`K&O)3!``*0"L*\``$.-G`*CKP0`!8T(``@E$`#&)/3_P*S\_\"L
M`AH%`/C_!XT"7@4``$X%``#_8S"@.`=\`"H%`"48:P`"/"<`)1AI`"0HK`#P
M_\>L)1AE`.W_#17X_\.L&`*K)V@`28P(`$(D?`!`K#@`0XP\`$6,9`!(C`@`
M1XPF2",!#`!&C"9`!0'X_T.,_/]%C"8XZ0`F,,@`)AAG`"8HI@!`*`4`PC<#
M`$`8`P`E**8`)1AE`.K_2Q1X`$.L@EH"/```B(P$`(6,&`"MCYEY0B0(`(>,
MPGX(`"``C(Q`&04`#`".C"%HH@$0`(F,0#$(`!@`BXPE&&\`@L`'``0`@*R`
M=PX`#`"`K"%HK`$4`("L)3##`!P`@*R`?P<`)A@K`2%HS0`D&&<`)3#8`25P
MY@$F,&L`(`"CCR$PI@&">`@`(1AB`"9H+@&`+P4`)&BH`2$8:P`F:*D!PLX&
M`"4HKP`H`*^/0,$&`"$8;0"`;P@`)<`9`R$8>``E:*4!(7CB`2<H!@`DP,T`
M)"BN`"%XZ0'"A@,`)2BX`$#!`P`A**\`)7@0`S``N(^"R`8`@#<&`"$HKP`A
MP`(#)7C9`"<P`P`DR&\`(7`.`\*&!0!`P04`)##-`"4PV0`A,,X`)7`0`S@`
MN(^"R`,`@!\#`"$PS@`AP`(#)7!Y`"<8!0`DR*X`(6@-`\*&!@!`P08`)!AO
M`"48>0`A&&T`)6@0`T``N(^"R`4`@"\%`"$8;0`AP`(#)6BY`"<H!@`DR,T`
M(7@/`\*&`P!`P0,`)"BN`"4HN0`A**\`)7@0`T@`N(^"R`8`@#<&`"$HKP`A
MP`(#)7C9`"<P`P`DR&\`(7`.`\*&!0!`P04`)##-`"4PV0`A,,X`)7`0`U``
MN(^"R`,`@!\#`"$PS@`AP`(#)7!Y`"<8!0`DR*X`(6@-`\*&!@!`P08`)!AO
M`"48>0`A&&T`)6@0`U@`N(^"R`4`@"\%`"$8;0`AP`(#)6BY`"<H!@`DR,T`
M(7@/`\*&`P!`P0,`)"BN`"4HN0`A**\`)7@0`V``N(^"R`8`@#<&`"$HKP`A
MP`(#)7C9`"<P`P`DR&\`(7`.`\*&!0!`P04`)##-`"4PV0`A,,X`)7`0`V@`
MN(^"R`,`@!\#`"$PS@`AP`(#)7!Y`"<8!0`DR*X`(6@-`\*&!@!`P08`)!AO
M`"48>0`A&&T`)6@0`W``N(^"R`4`@"\%`"$8;0`AP`(#)6BY`"<H!@`DR,T`
M(7@/`\*&`P!`P0,`)"BN`"4HN0`A**\`)7@0`W@`N(^"R`8`@#<&`"$HKP`A
MP`(#)7C9`"<P`P`DR&\`(7`.`\*&!0!`P04`)##-`"4PV0`A,,X`)7`0`X``
MN(^"R`,`@!\#`"$PS@`AP`(#)7!Y`"<8!0`DR*X`(6@-`\*&!@!`P08`)!AO
M`"48>0`A&&T`)6@0`X@`N(^"R`4`@"\%`"$8;0`AP`(#)6BY`"<H!@`DR,T`
M(7@/`\*&`P!`P0,`)"BN`"4HN0`A**\`)7@0`Y``N(^"R`8`@#<&`"$HKP`A
MP`(#)7C9`"<P`P`DR&\`(7`.`\*&!0!`P04`)##-`"4PV0`A,,X`)7`0`Y@`
MN(^"R`,`@!\#`"$PS@`AP`(#)7!Y`"<8!0`DR*X`(6@-`\*&!@!`P08`)!AO
M`"48>0`A&&T`)6@0`Z``N(^"R`4`@"\%`"$8;0`AP`(#)6BY`"<H!@`DR,T`
M(7@/`\*&`P!`P0,`)"BN`"4HN0`A**\`)7@0`Z@`N(^"R`8`@#<&`"$HKP`E
M,-D`(<`"`R=X`P`DR&8`)'CM`2'`#@/"A@4`)7#Y`4!Y!0`A<-@!)<#P`;``
MKX^"R`,`@!\#`"$0X@$A>-@!)7!Y`"<8!0`DP*X`)!AF`"%H30#"A@\`)1AX
M`$#!#P`A&&T`V6X"/"5H$`.X`+B/H>M"-(+(!0"`+P4`(<`"`R$8;0`E:+D`
M)BC-`2$P!@,F**\`(3#%`,``I8_"A@,`@L@/`$#!`P"`?P\`(2BB`"5X^0$E
MP!`#(3#8`"$HK@`FP*\!)L`#`X+(`P`A*+@`@,<#`,@`HX_"A@8`0'$&`"$8
M8@`EP!D#)7#0`2$HK@`A&&T`)G#X`29PQ@&"R`8`(1AN`(!W!@#0`*:/PH8%
M`"5PV0$A,,(`0&D%`"$PSP`F>`X#)6BP`29XY0$A&&T`@L@%`"$PSP"`?P4`
MV`"EC\*&`P!`:0,`(2BB`"5X^0$E:+`!(3#-`"$HN``F:,\!)FBC`8+(`P`A
M**T`@&\#`.``HX_"A@8`)6BY`2$88@""R`8`(1AN`"9P[0$F<,8!0,$&`"$8
M;@"`=P8`Z`"FCR7`$`,A*+@`(3#"`"5PV0$A,,\`)GBN`29XY0'"A@4`@L@%
M`$#!!0`A,,\`@'\%`/``I8\EP!`#(1AX`"$HH@`E>/D!(2BM`"9HSP$F:*,!
MPH8#`(+(`P!`P0,`(2BM`(!O`P#X`*./)<`0`R$PV``A&&(`)6BY`2$8;@`F
M<.T!)G#&`<*&!@""R`8`0,$&`"$8;@"`=P8```&FCR7`$`,A*+@`(3#"`"5P
MV0$A,,\`)GBN`29XY0'"A@4`@L@%`$#!!0`A,,\`@'\%``@!I8\EP!`#(1AX
M`"$HH@`E>/D!(2BM`"9HSP$F:*,!PH8#`(+(`P!`P0,`(2BM`(!O`P`0`:./
M)<`0`R$PV``A&&(`)6BY`2$8;@`F<.T!)G#&`<*&!@""R`8`0,$&`"$8;@"`
M=P8`&`&FCR7`$`,A*+@`(3#"`"5PV0$A,,\`)GBN`29XY0'"A@4`@L@%`$#!
M!0`A,,\`@'\%`"`!I8\EP!`#(1AX`"$HH@`E>/D!(2BM`"9HSP'"A@,`)FBC
M`4#!`P""R`,`(2BM`(!O`P`H`:./)<`0`R$PV``A&&(`)6BY`<*&!@!`P08`
M(1AN`"9P[0$EP!`#)G#&`2$HN`""R`8`(1AN`(!W!@`P`::/PH8%`$#!!0`A
M,,(`)7#9`27`$`,A&'@`(3#/`";`K@$FP`4#@L@%`"$PV`"`QP4`.`&EC\*&
M`P!`>0,`(2BB`"7`&0,E>/`!(2BM`"9HV`$A,,\`)FBC`8+(`P`A**T`@&\#
M`$`!HX_"A@8`0'D&`"$88@`E>/`!(2BO`"5XN0$F:`\#(1AN`"9HI@&"R`8`
M(1AM`(!O!@!(`::/PH8%`$!Q!0`A,,(`)7#0`2$8;@`E<+D!)FCN`2$PV``F
M:*4!(3#-`%`!K8_"A@,`@L@%`$#!`P"`+P4`(6BB`24HN0`EP!`#(3#8`"%H
MKP$FP,4!)L`#`\+.!@""@`,`(6BX`5@!N(]`>08`@!\#`!N/`CPE&'``W+Q"
M-"5X^0$A>*\!(<`"`R5HHP`DR*,`)&BF`2%P#@,E:+D!0,$/`,+.#P`A:*X!
M)7`9`V`!N(^"@`8`@#<&`"'``@,E,-``(7"N`25H9@`DR&8`(<`%`R1HKP$E
M:+D!(6BX`6@!N(_"A@X`0,D.`(*(#P"`+P\`(<`"`R4HL0`E>#`#(7BO`25H
MQ0`DR,4`(<`#`R1HK@$E:+D!(6BX`7`!N(_"A@\`0,D/`(*(#@"`'PX`(<`"
M`R48<0`E<#`#(7"N`25HHP`DR*,`(<`&`R1HKP$E:+D!(6BX`7@!N(_"A@X`
M0,D.`(*(#P"`-P\`(<`"`R4PT0`E>#`#(7BO`25H9@`DR&8`(<`%`R1HK@$E
M:+D!(6BX`8`!N(_"A@\`0,D/`(*(#@"`+PX`(<`"`R4HL0`E<#`#(7"N`25H
MQ0`DR,4`(<`#`R1HKP$E:+D!(6BX`8@!N(_"A@X`0,D.`(*(#P"`'P\`(<`"
M`R48<0`E>#`#(7BO`25HHP`DR*,`(<`&`R1HK@$E:+D!(6BX`9`!N(_"A@\`
M0,D/`(*(#@"`-PX`(<`"`R4PT0`E<#`#(7"N`25H9@`DR&8`(<`%`R1HKP$E
M:+D!(6BX`9@!N(_"A@X`0,D.`(*(#P"`+P\`(<`"`R4HL0`E>#`#(7BO`25H
MQ0`DR,4`(<`#`R1HK@$E:+D!(6BX`:`!N(_"A@\`0,D/`(*(#@"`'PX`(<`"
M`R48<0`E<#`#(7"N`25HHP`DR*,`(<`&`R1HKP$E:+D!(6BX`:@!N(_"A@X`
M0,D.`(*(#P"`-P\`(<`"`R4PT0`E>#`#(7BO`25H9@`DR&8`(<`%`R1HK@$E
M:+D!(6BX`;`!N(_"A@\`0,D/`(*(#@"`+PX`(<`"`R4HL0`E<#`#(7"N`25H
MQ0`DR,4`(<`#`R1HKP$E:+D!(6BX`;@!N(_"A@X`0,D.`(*(#P"`'P\`(<`"
M`R48<0`E>#`#(7BO`25HHP`DR*,`(<`&`R1HK@$E:+D!(6BX`<`!N(_"A@\`
M0,D/`(*(#@"`-PX`(<`"`R4PT0`E<#`#(7"N`25H9@`DR&8`(<`%`R1HKP$E
M:+D!(6BX`<@!N(_"A@X`0,D.`(*(#P"`+P\`(<`"`R4HL0`E>#`#(7BO`25H
MQ0`DR,4`(<`#`R1HK@$E:+D!(6BX`=`!N(_"A@\`0,D/`(*(#@"`'PX`(<`"
M`R48<0`E<#`#(7"N`25HHP`DR*,`(<`&`R1HKP'"A@X`@H@/`"5HN0&`-P\`
MV`&OCT#)#@`A:+@!)3#1`"7`,`,AP+@!(7CB`25H9@`DR&8`)&BN`2%XY0'"
MAA@`)6BY`4#)&``A:*\!)7@P`^`!N8^"B`X`@"\.`"'((@,E*+$`(7BO`25P
MQ0`D@,4`(6@C`R1PV`%`R0\`@H@8`"5PT`&`'Q@`Z`&XC\*&#P`A<,T!)1AQ
M`"5H,`,A<,T!(<`"`R5HHP`DR*,`)&BO`2'`!@."B`\`)3"Y`8!O#P#P`:^/
MPH8.`$#)#@`A,-@`)6BQ`27`,`,A$.(!(<#8`"4P;0`D>&T`(2A%`"0PS@`E
M,,\`(3#%`/@!I8]BR@(\@L@.`-;!0C2`=PX`(2BB`"5PV0'"AA@`0'D8`"$H
MHP`F&*X!)7CP`288>``A,,\`(2BC```"HX_"A@8`@L@8`$!Y!@"`QQ@`(1AB
M`"7`&0,E>/`!(2BO`"$8;0`F>-@!)GCF`8+(!@`A&&\`@'\&``@"IH_"A@4`
M)7CY`2$PP@!`:04`(3#.`"9P#P,E:+`!)G#%`2$8;0""R`4`(3#.`(!W!0`0
M`J6/PH8#`$!I`P`A**(`)7#9`25HL`$A,,T`(2BX`"9H[@$F:*,!@L@#`"$H
MK0"`;P,`&`*CC\*&!@`E:+D!(1AB`(+(!@`A&&\`)GC-`29XY@%`P08`(1AO
M`(!_!@`@`J:/)<`0`R$HN``A,,(`)7CY`2$PS@`F<*\!)G#%`<*&!0""R`4`
M0,$%`"$PS@"`=P4`*`*ECR7`$`,A&'@`(2BB`"5PV0$A**T`)FCN`29HHP'"
MA@,`@L@#`$#!`P`A**T`@&\#`#`"HX\EP!`#(3#8`"$88@`E:+D!(1AO`"9X
MS0$F>.8!PH8&`(+(!@!`P08`(1AO`(!_!@`X`J:/)<`0`R$HN``A,,(`)7CY
M`2$PS@`F<*\!)G#%`<*&!0""R`4`0,$%`"$PS@"`=P4`0`*ECR7`$`,A&'@`
M(2BB`"5PV0$A**T`)FCN`29HHP'"A@,`@L@#`$#!`P`A**T`@&\#`$@"HX\E
MP!`#(3#8`"$88@`E:+D!(1AO`"9XS0$F>.8!PH8&`(+(!@!`P08`(1AO`(!_
M!@!0`J:/)<`0`R$HN``A,,(`)7CY`2$PS@`F<*\!)G#%`<*&!0""R`4`0,$%
M`"$PS@"`=P4`6`*ECR7`$`,A&'@`(2BB`"5PV0$A**T`)FCN`<*&`P`F:*,!
M0,$#`(+(`P`A**T`@&\#`&`"HX\EP!`#(3#8`"$88@`E:+D!PH8&`$#!!@`A
M&&\`)GC-`27`$`,F>.8!(2BX`(+(!@`A&&\`@'\&`&@"IH_"A@4`0,$%`"$P
MP@`E>/D!)<`0`R$8>``A,,X`)L"O`2;`!0."R`4`(3#8`(#'!0!P`J6/PH8#
M`$!Q`P`A**(`)<`9`R5PT`$A**T`)FCX`2$PS@`F:*,!@L@#`"$HK0"`;P,`
M>`*CC\*&!@!`<08`(1AB`"5PT`$A**X`)7"Y`29H#@,A&&\`)FBF`8+(!@`A
M&&T`@&\&`(`"IH_"A@4`0'D%`"$PP@`E>/`!(1AO`"5XN0$F:,\!(3#8`"9H
MI0'"A@,`(3#-`(@"K8]`P0,`@L@%`"7`$`.`+P4`(<#8`"%HH@$E*+D`(6BN
M`4`Q&``F<.4!PH88`"9PPP&"R`,`(6BN`8!W`P`E&-``D`*FCR%HHP$A,,(`
M)1#9`288H@`A,,\`)AAX`,+.#0!`<0T`(3##`()X&`"`'Q@`)7#9`2$PS@`E
M&&\`(4AI`"$02P`A0,@`$`")K"$X[0`8`(*L(2BL````B*P(`(>L(`"%K"0`
M@*R<`J./``!"C04`8A2L`K^/J`*QCZ0"L(\(`.`#L`*])VB!F8\)^"`#````
M``(`'#Q<\YPG(>"9`\C_O2<0`+RO-`"_KS``MJ\L`+6O*`"TKR0`LZ\@`+*O
M'`"QKT,`@!`8`+"OG(""CP``58P_`*`2````````@H`,`$`0)9```#T``R0)
M`$,0`````"60@``!`%(F``!"@@,`0!``````^_]#%``````CD$0"``"PCA,`
M`!(]`!8D)9B@`"6@@``EB*`"H("9CR4@``(E,$`""?@@`R4H@`(A&!("!`!`
M%!``O(\``&*`$`!6$``````$`#$F```PCO/_`!:@@)F/-`"_CR40``(P`+:/
M+`"UCR@`M(\D`+./(`"RCQP`L8\8`+"/"`#@`S@`O2<CB#4"`0!2)H.($0`A
M@!("``!QKC0`OX\E$``",`"VCRP`M8\H`+2/)`"SCR``LH\<`+&/&`"PCP@`
MX`,X`+TGY/\`$"6````"`!P\%/*<)R'@F0/(_[TG+`"SKS``M*\8`+0G*`"R
MKR0`L:\EB(``(`"PKQ``O*\T`+^O@(&3CR2`D(^<@)*/``!BCM0L$"8<`**O
M)2B``B7(``*8_Q$$)2`@`A(`0!`0`+R/&`"BCX`8`@```$*.(1!#``0`0XST
M_V`0``!#K`0`0B0$`$.,_?]@%```0ZPE*(`")<@``H?_$00E("`"\/]`%!``
MO(\<`*./``!BC@@`8A0T`+^/,`"TCRP`LX\H`+*/)`"QCR``L(\(`.`#.`"]
M)VB!F8\)^"`#``````(`'#PT\9PG(>"9`[C_O2<,@9F/)`"PKR6`H``0`+RO
M`0"E)$0`OZ\T`+2O,`"SKR68@``H`+&O0`"WKSP`MJ\X`+6O+`"RKP```H*`
M@9&//0!".`J`H@```"..)2```AP`HZ\)^"`#`````!@`I2<0`+R/)2!@`B2`
MF8_4+#DG5?\1!"6@0`!:`$`0$`"\CPR!F8\E($``"?@@`R600``K$%0`1P!`
M$!``O(\8`+*/G("6CX"H$@```&*"?0!`$#T``R1[`$,0``````,``!`E(&`"
M!0!#$``````!`(0D``""@/O_0!0`````(R"3````THX"`)0F+(&9CR$@A`()
M^"`#(9!5`A``O(]N`$`0``!"KA@`HX\!`&0F``#"C@``98*`&`,`(1!#````
M0XP-`*`0``!EH#T``B0*`*(0``````,``!`]``4D!@!%$``````!`(0D__^"
M@`$`8R3Z_T`4``!BH#T`!"0!`&(D``!DH`$`$";__P."`0!")/S_8!3__T.@
M)1```!P`I(\``"..3@"#%$0`OX]``+>//`"VCS@`M8\T`+2/,`"SCRP`LH\H
M`+&/)`"PCP@`X`-(`+TG`0`0)O__`H(!`%(F[?]`$/__0J(!`!`F__\"@@$`
M4B;W_T`4__]"HN?_`!`E$```G("6CP``UXX``.*.+@!`$"40X`("```0)1@`
M`"480`($`$(D``!$C/S_@!0!`'(D`P!C)(`@`P`H@(*/\+%#C!``8!`L@9F/
M,(&9CR4H@``)^"`#)2#@`A``O(\=`$`0``#"KH"H$@`E&$```0!")H`0`@`A
M&&(```!@K)'_`!`8`+*O`0`#)`GX(`/PL4.L$`!`$!``O(^,@9F/@*@2`"4H
MX`(E,*`""?@@`R4@0``0`+R/)1A``.S_`!```,*NCO\`$"4@```(``0DVO\`
M$"60``"P_P`0__\")&B!F8\)^"`#``````(`'#Q8[IPG(>"9`Q#_O2?8`+.O
M&`"\K^P`OZ_H`+>OY`"VK^``M:_<`+2OU`"RK]``L:_,`+"O@(&3CP``8H[$
M`**O!`"`$````````(*`#P!`%"6(@`#$`*./``!BCFT`8A3L`+^/Z`"WC^0`
MMH_@`+6/W`"TC]@`LX_4`+*/T`"QC\P`L(\(`.`#\`"])X2`F8\)^"`#````
M`!@`O(_M_T`0)9!``"2`E(\@`+<G)("5C\1<E";8,;4FK("9CPGX(`,E($`"
M$P!`$!@`O(\3`$.0+@`$)",8@P`7`&`4`````!0`0Y#U_V`0K("9CR,@@P!"
M`(`0`````",@!``0`(`4K("9CPGX(`,E($`"[_]`%!@`O(^(@)F/"?@@`R4@
M0`(8`+R/=(&9CPGX(`,E("`"R/\`$!@`O(_@_V`0K("9CPR!F8\E("`""?@@
M`Q,`4"0E(``"&`"\CPR!F8\)^"`#);!``!@`O(\A$,("+(&9CPGX(`,"`$0D
M__\&)!@`O(\!``4D)2!``!0`L*\E.(`"$`"QKX"`F8\)^"`#);!```,`!"08
M`+R/)3#@`IB`F8\)^"`#)2C``O__`R0&`$,0&`"\CS@`HH\`0`,D`/!",`P`
M0Q`ER*`"7(&9CPGX(`,E(,`"&`"\CXB!F8\)^"`#)2#``K#_`!`8`+R/O_\`
M$!4`1)!]_Q$$)2#``O;_`!`8`+R/:(&9CPGX(`,``````@`</#3LG"<AX)D#
MV/^])Y2`F8\<`+"O$`"\KR0`OZ\@`+&O)8B``&"!D(\)^"`#```$C@,`!"00
M`+R/2`%&))"`F8\)^"`#)2@@`@<`0!`0`+R/)`"_CR40```@`+&/'`"PCP@`
MX`,H`+TGE("9CPGX(`,```2.`$`#)&`!0HP`\$(P"0!#$!``O(^4@)F/"?@@
M`P``!(X`H`,T8`%"C`#P0C#K_T,4$`"\C\B`F8\"``4D"?@@`R4@(`(D`+^/
M`0!"+"``L8\<`+"/"`#@`R@`O2<"`!P\8.N<)R'@F0/([[TG4(&9C_\/!B0H
M$+*O$`"\KS`0M*\EH*``+!"SKR68@``D$+&O'`"Q)S00OZ\@$+"O)2@@`H"!
MDH\D@(2/``!"CLQ<A"0<$**O"?@@`P`````G`$`8$`"\C___4"0@$*,G(1AP
M`/SO8X`?`&`0X("9CR6`0``O``4D)3```@GX(`,E("`"&@!`$!``O(]@@8*/
ME("9CPGX(`,``$2,)3@``A``O(\E,"`")2A@`K2`F8\)^"`#)2!``!``O(\<
M$*./``!"CA8`8A0T$+^/,!"TCRP0LX\H$+*/)!"QCR`0L(\(`.`#.!"])^+_
M`!8`````8(&"CY2`F8\)^"`#``!$C"4P@`(0`+R/)2A@`DR!F8\)^"`#)2!`
M`.C_`!`0`+R/:(&9CPGX(`,``````@`</"3JG"<AX)D#X/^])V"!@H^4@)F/
M$`"\KQP`OZ\)^"`#``!$C!``O(\E($``'`"_CR``O2<L@(>/)("%CWB!AH_X
M@)F/])WG)`@`(`/<7*4D`@`</-#IG"<AX)D#V/^])Y2`F8\@`+"O)`"_KQ@`
MO*]@@9"/"?@@`P``!(X8`+R/,("9C]W_$00E($``&`"\CY2`F8\)^"`#```$
MCA@`O(\E($``%`"@KR2`AX\D@(6/S("9CSQ@YR0T@(:/^%RE)`GX(`,0`*>O
M)`"_CR``L(\(`.`#*`"])P(`'#Q(Z9PG(>"9`\#?O2<X@9F/-""QKQ@`O*\\
M(+^O,""PKR0`L"<X(+*O@(&1CP``(HXL(**O"?@@`P`````!$`8D&`"\CP$`
M!200`**O)2```B2`@H\D@(>/@("9CQQ=0B007><D"?@@`Q0`HJ\C`$`$&`"\
MCU"!F8\H$+(G`!`&)"4@``()^"`#)2A``A@`O(\:`$`$)8!``"R!F8\)^"`#
M`0!$)!@`O(\*`$`0)1A``(2!F8\E,``")2A``@GX(`,E($``(8!0`!@`O(\E
M&$``````HBP@I(\E$&`````CC@@`@Q0\(+^/.""RCS0@L8\P(+"/"`#@`T`@
MO2?U_P`0)1@``&B!F8\)^"`#``````(`'#PTZ)PG(>"9`SB`F8^V_P`0````
M``(`'#P<Z)PG(>"9`Z#OO2>`@8*/)("9CR``O*]<$+^OU"PY)T`0LJ\\$+&O
M)8B@`#@0L*\E@(``6!"^KS``I2=4$+>O4!"VKTP0M:]($+2O1!"SKRP`HJ\D
M@(2/``!"C"1=A"0T$**O%?T1!``````O``4D(`"\CR4@``(4@9F/"?@@`R60
M0``9`$`0(`"\CR2`A(\E*``")("9C_PN.2>1_1$$,%V$)"40``(@`+R/+`"C
MCS00I(\``&.,@0"#%%P0OX]8$+Z/5!"WCU`0MH],$+6/2!"TCT00LX]`$+*/
M/!"QCS@0L(\(`.`#8!"])PR!F8\D@)2/"?@@`R4@``(E("`"(`"\CT!=A2;$
M@)F/"?@@`R6X0``@`+R/W/]`$"7P0``D@(*/)("6CR2`E8\H`**O``#"@TQ=
MUB9#`$`01%VU)@8`0!*D@9F/)2C``PGX(`,E($`",@!`$"``O(\,@9F/"?@@
M`R4@P`,O``0D(1C"`___98`'`*04(`"\CR\`!23__V"@__]C)/__9(#\_X40
M__]")`$`XR8A$&(``!!"*+K_0!"`@)F/-`"Q)P`0!B1@@9./`0`%)!@`L*\E
M.*`"%`"VKR4@(`()^"`#$`"^KR``O(^4@)F/"?@@`P``9(X#``0D(`"\CT@!
M1B28@)F/"?@@`R4H(`()`$`4(`"\CY2`F8\)^"`#``!DC@"``S1@`4*,`/!"
M,!<`0Q`@`+R/Q("9CT!=A28)^"`#)2```"``O(^5_T`0)?!`````PH.__T`4
M``````<`0!(E($`"*`"BCZ2!F8\)^"`#(%U%).__0!`@`+R/*`"BCR!=7B3(
M_P`0`0`"),B`F8\!``4D"?@@`R4@(`+E_T`4(`"\CR2`A(\E*"`")("9C_PN
M.2<0_1$$,%V$)"``O(_L@)F/"?@@`R4@(`)\_P`0(`"\CVB!F8\)^"`#````
M````A8`'`*`0)1"```$`@R0O`*0X``!E@`H09`#\_Z`4`0!C)`@`X`,`````
M`@`</"#EG"<AX)D#V/^])Q``O*\D`+^O(`"QKR(`@!`<`+"O``"1@!\`(!(E
M@(``#(&9CPGX(`,`````__]")"$0`@(K&`(",0!@$!``O(\``$2`+P`#)"0`
M@Q0`````!```$"\`!"0``$.`'P!D%`````#__T(D^_\"%@`````O``(D"``B
M$B2`A(\D`+^/(`"QCQP`L(],780D[("9CP@`(`,H`+TG+(&9CPGX(`,"``0D
M!P!`$"X`!"0``$2D)`"_CR``L8\<`+"/"`#@`R@`O2<D`+^/)1```"``L8\<
M`+"/"`#@`R@`O2<$```0+P`$)```0X`'`&00`````/__0B0K&`("^O]@%```
M``#;_P(2``````0``!`O``0D``!#@`4`9!0`````__]")"L8`@+Z_V`4````
M`",04``"`$,D`1!C+.+_8!`H@)&/`!`')-2`F8\!`$8D)2@``@GX(`/PH20F
M\*$B)B0`OX\@`+&/'`"PCP@`X`,H`+TG`@`</*#CG"<AX)D#D/^])RR`@H\@
M`*,G5`"RK]"=0B00`+RO;`"_KR``121H`+>O9`"VKV``M:]<`+2O6`"SKU``
ML:],`+"O@(&2CP``1(Y$`*2O``!(C!``0B00`&,D\/]HK/3_1XSX_T:,_/]$
MC/3_9ZSX_V:L]O]%%/S_9*PD@)"/'`"S)R2`A(\``$*4'"X0)B2`E(]0780D
M)("5CR7(``(Y_!$$``!BI"7(``(0`+R/)("$CR2`EH\D@)>/,OP1!%Q=A"0E
MR``"$`"\CR2`A(\M_!$$9%V$)"7(``(0`+R/)("$CRC\$01P780D)<@``B7\
M$01X780F)<@``A``O(\D@(2/(/P1!(A=A"0ER``"'?P1!"1=I"8ER``"&OP1
M!)1=Q"8ER``"%_P1!*!=Y"8ER``"$`"\CR2`A(\2_!$$K%V$)"7(``(0`+R/
M)("$CPW\$00P780D)<@``A``O(\D@(2/"/P1!+A=A"0ER``"$`"\CR2`A(\#
M_!$$Q%V$)"4H8`(0`+R/)("1CR2`A(_4+#$F)<@@`JG[$030780D$`"\CT\`
M0!`E*$``)("0C_PN$"8ER``"*_P1!*!=Y"80`+R/)("$CR4H8`(ER"`"F_L1
M!.1=A"0'`$`0$`"\CR2`A(\E*$``)<@``A[\$03X780D$`"\CR2`A(\E*&`"
M)<@@`H[[$00$7H0D&@!`$!``O(\D7:0F)<@``A+\$00E*$``$`"\CR2`A8]X
M780F)<@``@S\$00T7J4D1`"CCP``0HXJ`&(4$`"\CVP`OX]H`+>/9`"VCV``
MM8]<`+2/6`"SCU0`LH]0`+&/3`"PCP@`X`-P`+TG)("$CR4H8`(ER"`";OL1
M!!1>A"0'`$`0$`"\CY1=Q"8ER``"\OL1!"4H0`#@_P`0$`"\CR2`A8\*``8D
MH("9CS$`I"<)^"`#*%ZE)-C_0!00`+R/.P"E)R7(``+D^Q$$E%W$)M+_`!`0
M`+R/)("0C[;_`!#\+A`F:(&9CPGX(`,``````@`</*#@G"<AX)D#T/^])___
M`R0H`+&O)`"PKQ``O*\L`+^O@(&0CRB`D8\```2.$*`BCAP`I*\)`$,0)("$
MCQP`I(\```..%@"#%"P`OX\H`+&/)`"PCP@`X`,P`+TG&`"E)R2`F8_4+#DG
M-?L1!)1=A"0(`$`0$`"\CP``0H`%`$`0`````#``0C@K$`(`Z_\`$!"@(JXE
M$```Z/\`$!"@(JYH@9F/"?@@`P`````"`!P\\-^<)R'@F0/@_[TG9(&9CQ``
MO*\<`+^O"?@@`P`````0`+R/E(&9CPGX(`,E($``!0!`$````````$*,'`"_
MCP@`X`,@`+TG_/\`$"40```"`!P\G-^<)R'@F0,D@(*/>/^])SA>0B1H`+*O
M?`"WKR600`!$`**O)(""CX"!EX]X`+:O4%Y")'``M*]@`+"O):"``$@`HJ\D
M@(*/)("$CR2`D(]87D(D)("6CX``OJ\\`+XG3`"BKT!>$"8D@(*/=`"UKVP`
MLZ]@7D(D9`"QKR``O*]``+$G4`"BKX0`OZ\P`*2O0%W$)B2`@H\``...)("3
MCR2`E8]T7D(D+`"DK]0L<R9``+"O_"ZU)EP`HZ]4`**O"@``$%@`H*\E*(`"
M"?@@`R4@P`(E`$`0(`"\CQ0`0!($`#$F)8!``@0`,HXE*,`#)<A@`M'Z$00E
M(``"(`"\CP0`0!`EL$````!"@.[_0!2H@9F/)2B``B7(H`)1^Q$$)2```@0`
M,2;N_T`6(`"\CUP`HX\``.*.+P!B%(0`OX^``+Z/?`"WCW@`MH]T`+6/<`"T
MCVP`LX]H`+*/9`"QCV``L(\(`.`#B`"])PR!F8\)^"`#)2"``B4@P`(@`+R/
M#(&9CPGX(`,T`**O(`"\CS0`I8\A$*(`+(&9CPGX(`,"`$0D__\&)"``O(\E
M2$``,`"CCP$`!20L`**/)2`@`30`J:\8`+:O1%UG)!0`HJ^`@)F/"?@@`Q``
MM*\E(``"-`"ICR7(H`(>^Q$$)2@@`;K_`!`@`+R/:(&9CPGX(`,``````@`<
M/)3=G"<AX)D#$("])R2`AX\P@0,T__\"/.A_OJ_<?[6O):B``-A_M*\$?T4D
MU'^SK\A_L*_L?[^OY'^WK^!_MJ_0?[*OS'^QKWC^O2>`@9Z/(`"D)R2`E(\H
M`+RO(1AD`"2`A(\``,:/U"R4)B$08@!$`*>O^%V0)"2`A(\P@0,T$']`K"7(
M@`*`7I,D(']0K"``I"<T?T"L%']3K"$89``<?T"L)%WD)"$H90`D@(./(`"G
M)Y!>8R0(?T.L)("#CR!=8R0,?T.L+($#-"$89P```&:L)("#C_Q=8R0D?T.L
M)("#CYA>8R0H?T.L)("#CRA=8R0L?T.L)("#CZ!>8R0P?T.L)("#CZ1>8R1)
M^A$$&']#K`0`0!`H`+R/``!#@(,!8!0\@)F/0("9CQS_$00`````*`"\CX@!
M0!`ED$``#(&9CPGX(`,E($`"*`"\CT`0`@`L@9F/"?@@`P$`1"0``$.")8A`
M`!$`8!`H`+R/)("#CR68(`*P7G8D``!"D@$`4B:`@)F/__\&)`$`!20E(&`"
M$`"BKPGX(`,E.,`"`@!S)@``0H+T_T`4*`"\C___%CPD@)./(`"C)S"!`C0E
M(``"(1!#`"!_T"8$?]8F(8!0`#"!`C3\,W,F(1!#``4``!`AL%8`!``0)@``
M!(X4`(`0`````"7(@`(-^A$$)2C``B@`O(_W_T`0)9!`````0H#T_T`0)<A@
M`L_[$00E($`"\/]`$"@`O(_L@)F/"?@@`R4@0`(H`+R/'P!`%"6`0``@`*0G
M)("2CS"!`S3__P(\(1AD``A_4R0A$&(`);```/PS4B8(?U",,($"-"$01``A
MF%,````"@@X`0!``````@+@6`"&X=P(ER$`"LOL1!"4@``)<`$`4*`"\CP0`
M\(X$```2`0#6)@```H+V_T`4!`#W)B6````,@9F/"?@@`R4@``(E("`"*`"\
MCPR!F8\)^"`#);!``"@`O(\AL,("!`36)BR!F8\)^"`#)2#``O__!B0H`+R/
M)2!``"600``<`+&O`0`%)!``L*\D@)./)(""CR2`AX^`@)F/3%US)L1>0B2X
M7N<D%`"SKPGX(`,8`**OP`$%)"@`O(_P@)F/"?@@`R4@0`+__P,D00!#$"@`
MO(]@@9&/E("9CPGX(`,``"2.`P`$)"@`O(](`48DD("9CPGX(`,E*$`"*`"\
MCT@`0!`E@$``D(&"CP$`!20D@(:/)8@``*B`F8\``*>.``!$C$Q?QB0)^"`#
M$`"RKR@`O(\@`*,G+($"-"$00P```$2,)1`@`@``PX_3`H,4:(&9CX@!O2?L
M?[^/Z'^^C^1_MX_@?[:/W'^UC]A_M(_4?[./T'^RC\Q_L8_(?["/"`#@`_!_
MO2?L@)F/"?@@`R4@``(H`+R/I_]`%"6`0``@`*,G,($"-`$`UB8A$$,`__\#
M/(`@%@`A$$,`(1!$``A_4(R+_P`6`````)K_`!`E@```Y("9CPGX(`,`````
M$0`#)```0HRZ_T,0*`"\CY"!@X\!``4D)("&CR6(`````*>.J("9CP``9(S,
M7L8D%`"BKPGX(`,0`+*OQ?\`$"@`O(^4@)F/"?@@`P``)(X`0`,D8`%"C`#P
M0C"R_T,4*`"\CY2`F8\)^"`#```DCB@`O(]D@9F/"?@@`V@!5XRI_^(6*`"\
MCY2`F8\)^"`#```DCL`!`R1@`4*,_P%",*'_0Q0H`+R/+(&9CPGX(`,E(,`"
M(`"C)R@`O(\EB$``__\%/#"!`C0$?Z4D)("$CR$00P`ER(`"(2A%`#SY$018
M7H0DK`!`$"@`O(_L@)F/)2!```GX(`,``+2.*`"\CR4@@`)$@)F/`?P1!"4H
M0``H`+R/H`!`$"6@0``,@9F/"?@@`R4@@`(EL$``!`!"*!``0!0H`+R/)("%
MC_S_Q":D@9F/(2"$`@GX(`,(7Z4D"`!`%"@`O(\$``(D``+"$B&PE@(O``(D
M^__#@OP!8A``````2("9C\3]$00`````"`!`%"@`O(\$@9F/)2@```GX(`,E
M((`"*`"\CX``0!1``**O)(""C___%B0D@(6/$0`7)"2`A(_\+EDD-%ZE))1=
MA"2,^1$$-`"YKR@`O(\X@9F/"?@@`P````#__P8D*`"\CP$`!20E("`"&`"B
MKQ0`LZ\0`+*O)("4CR2`AX^`@)F//&"4)BA?YR0)^"`#'`"TKR@`O(\D@)6/
M%P``$#A?M2;D@)F/"?@@`P```````$*,%P!7%"@`O(\X@9F/"?@@`P$`$";_
M_P8D*`"\CP$`!20@`+2O)3B@`AP`L*\E("`"&`"BKQ0`LZ^`@)F/"?@@`Q``
MLJ\H`+R/\("9C\`!!20)^"`#)2`@`N7_5A`H`+R/B(&9CPGX(`,E($`")2@@
M`D0`HH\T`+F/"?@@`R1=1"0H`+R//("9C[3]$00E("`"(_\`$"@`O(\E($``
MK_T1!#0`HJ\H`+R/-`"BC^R`F8\)^"`#)2!``"@`O(\8_P`0)8A``"``HR<P
M@0(T__\1/"$00P`$?S<F(8A1`#"!`C0!`!8D(1!#`"4@8`(&```0(;A7`(`0
M%@`A$"("%']$C!``@!`!`-8F)<B``J/X$00E*.`"]_]`$"@`O(\``$.`]/]@
M$.R`F8\)^"`#)2!``"@`O(_O_T`0)9!``%O^`!`,@9F/+(&9CPGX(`,-``0D
M*`"\CR6(0``D@)*/7OX`$(A>4B9@_P`0``"TCCR!F8\"`!8D[O\&)/__!R00
M`+:O)2!```GX(`,EJ$``*`"\CR``HR?__Q`\,($"-/Q_%"8A$$,`G(&9CP8`
M!B0AH%0`)2"@`@GX(`,E*(`",($"-"``HR<A$$,`(8!0`/Q_`I(%`$`4*`"\
MC_U_`I)#``,D@@%#$$$``R0\@9F/)3```$``I(\E.```"?@@`Q``H*\@`*0G
M,($#-"@`O(___P(\(1AD`#A_2B0A$&(`)("4CS"!`S0E*```(1AD`+!_0*S_
M_P0\/']%K"4H``#\?X0T(;AD`$1_1:P@`*0G,($#-$P`MZ\E*```(1AD`$5G
M!#Q,?T6L)2@```$CA#0X?T2LS>\$/"&P:@!4?T6LB:N$-$!_1*RZF`0\L!F#
M)O[<A#1(?T2L,A`$/"4H```\`*.O=E2$-%!_1*S2PP0\.`##)EQ_1:SPX80T
M)2@``%A_1*PE(```2`"CKR6@0`!D?T6L8']$K&A_1*QL?T6LG(&9CP"`!C1`
M`*2/"?@@`R4HX`(H`+R/<0!`&"6H0`!@?X6.P"`5`&1_@H[#'Q4`90!`%"$@
MA0`K*(4`8@"@%`````!H?X6.;'^&CL`X`P"P?Y".0A<5`&!_A*Y"'P,`9'^`
MKB40X@`A($4`(1AF`"L0@@!H?X2N(1!#`$H``!)L?X*N2`"BCT```R2$@9F/
M3`"ECR$@4``T`*.O(Q!P`"J`50`*$+`")3!```GX(`,E@$``L'^"CC0`HX\H
M`+R/(1`"`L[_0Q2P?X*N/`"YCR4@P`()^"`#(ZBP`DP`HH\H`+R/(1!0`#@`
MHJ]``*(J)`!`%#@`HH\E@*`"<'^#)D``320#`$R($`!C)`<`1H@+`$6(#P!$
MB```3)@$`$:8"`!%F`P`1)@0`$(D\/]LK/3_9JSX_V6L\O]-%/S_9*P\`+F/
MP/\0)C0`HJ\)^"`#)2#``D```RHH`+R/Y_]@$#0`HH_`_Z(FP/\#)#\`53`D
M$$,`.`"CCT``0B0A$&(`.`"BKR2!F8](``<D.`"ECR4PH`()^"`#2`"DCR@`
MO(^7_P`0L'^5KB``HR<P@0(T(1!#`/__`SS\?V,T(1!#`,K_`!`X`**O:'^&
MCFQ_@HX!`,4D*S"F`)S_`!`A,,(`C("9CPGX(`-``*2/(`"C)S"!`C0H`+R/
M@/\%)"$00P#__P,\(1!#`"``HR=@?U",:']7C#"!`C3`*`1^(1!#`/__`SPA
M$$0``0"$)"$08@`Y`(,HEP!@$'!_1:`@`*,G]("9CS"!`C0X``8D(1!#`/__
M`SPC,,0`(1!#`"4H``!P?T(D"?@@`R$@1``@`*4G/`"YCS"!`C3__Q4\(1!%
M``(R%P`AL%4`(`"G)P(>%P"J?\:B,($&-`(4%P"H?\.B(3#'`*M_UZ(X?Z0F
MJ7_"H@(N$`"O?]"B`AP0``(2$`"L?\6B(2#$`*U_PZ*N?\*B"?@@`]!_L"8@
M`*,G,($"-#A_R(XH`+R/(1!#`$!_QXY(?\:.`E0(`"&@50!0?\6.,($"-%A_
MQ(X"2@@`O7_*HB$00P"_?\BB`F8'`+Y_R:("7`<`PW_'H@)2!P#`?\RB(8!0
M`,%_RZ("%@@`PG_*H@).!@#'?\:B`D0&`+Q_PJ+$?\FB`FH&`,5_R*("9@4`
MQG_-H@)<!0#(?\RB`E(%`,E_RZ("3@0`RG_*H@)$!`#+?\6B`CH$`,Q_R:*]
M?Y0FS7_(HB@`%R;.?\>BSW_$HB2`@X\#```0L%YU)```@I(!`)0F@("9CR4@
M``+__P8D$`"BKP$`!20"`!`F"?@@`R4XH`+U__`6*`"\CR``I2<D@(>/,($$
M-("`F8___P(\%`"SKR$@A0`0`+*OT']#)"$0@@`P@00T__\&)"$@A0`87^<D
M(1B#`"2`A(\!``4D&`"CKSQ@A"0<`*2O)2`@`OA_0*`)^"`#`````"@`O(\D
M@(*/_"Y")$[^`!`T`**O!`"UC@/^H!(,@9F/"?@@`R4@H`($`$,L_OU@%"@`
MO(\D@(6/_/]")*2!F8\A(*(""?@@`Q!?I20H`+R/]?T`$`J@H@+__P(\]("9
MCR``HR<X?U8D,($"-$``!B0A$$,`(S#$`"&P5@`E*```.`#5)@GX(`,A(*0"
M/`"YCPGX(`,E(,`".`#`KCP`P*Y``,"N1`#`KD@`P*Y,`,"N4`#`KE0`P*Y8
M`,"N7`#`KF``P*YD`,"N:`#`KEC_`!!L`,"N_G\$DG[^@Q0\@9F/_W\#DGS^
M8A0E,```4`&CDT@``B1X_F(440&CDT4``B1U_F(4__\')$``L(\\@9F/QO\&
M)!``MJ\)^"`#)2```BD`!B0H`+R/)2B``IR!F8\)^"`#)2```O__!B0H`+R/
M`0`%)"4@(`(8`+2O%`"SKQ``LJ\D@(*/)("'CX"`F8\\8$(D&%_G)*/_`!`<
M`**O"?@@`P`````"`!P\:,Z<)R'@F0.H_[TGE("9CR@`HB<T`+&O'`"BKR6(
M0``X`+*O5`"_KQ``O*\P`+"O4`"^KTP`MZ](`+:O1`"UKT``M*\\`+.O@(&"
MCV"!DH\D`**O``!"C```1(XL`**O"?@@`P`````0`+R/)8!``)2`F8\)^"`#
M``!$CB4H(`(0`+R/9`!"D"2`@X\D@(2/90`"HM0L>21X780DFO81!"``N:\%
M`$`0$`"\CP``1(`Q``,DZ@"#$`````!,@)F/@/H1!``````0`+R/E("9CPGX
M(`,``$2."P`')!``O(\!``8D)2!``"2`A8\H@9F/"?@@`Z!?I21%`$`0$`"\
MCRB`DX\0`$.,^+%BC@(`0B@_`$`4&`!TC"``%3PH@)>/)8@```$`$"0`!+4F
M#```$``$%B2D@9F/)2#``PGX(`,0`,6,+@!`%!``O(_XL6*.`0`0)BH8`@(J
M`&`0`0`Q)I2`F8\)^"`#``!$CB4X```0`+R/)2B``B4P(`+`@)F/"?@@`R4@
M0``0`+R/'`!`$"4H0````$:,@!@0`/2QY(X(`,*,(1B#`"0050#A_U80``!^
MC)2`F8\``$2."?@@`Q@`I:\"``<D$`"\CR4P```8`*6/)2!``$B!F8\)^"`#
M``"EC"4@P`,0`+R/I(&9CPGX(`,E*$``U/]`$!``O(_XL6*.__]#)(,`<1`"
M`$(HE("9CPGX(`,``$2.`P`')!``O(\!``8D)2!``"2`A8\H@9F/"?@@`ZA?
MI200`+R/$@!`$"6`0`"4@)F/"?@@`P``1(X0`+R/)2!``!```XXD@(:/3(&9
MCP``98P)^"`#K%_&)!```HX``$*,"`!"C(`%0GR4`$`4$`"\CY2`F8\)^"`#
M``!$C@,`!R00`+R/`0`&)"4@0``D@(6/*(&9CPGX(`.T7Z4D$`"\CQ4`0!`E
M@$``)("$CR``N8\<`*6/"?@@`S!=A"00`+R/)8A`````1(YO`$`0E("9CPGX
M(`,`````)3`@`A``O(\E($``$``#CDR!F8\)^"`#``!EC!``O(^4@)F/*("1
MCPGX(`,``$2.$`"\CR6`0`"4@)F/"?@@`P``1(X!``8D$`"\CR4@0``D@(6/
M`(&9CPGX(`.X7Z4D)2```A``O(\E*$``)("&CTR!F8\)^"`#T%_&)!``O(^4
M@)F/"?@@`P``1(X0`+R/'`"ECR``N8]E`$"@)("$CPGX(`,D780D$`"\CR6`
M0``S`$`0_+$BKO"`F8_``04D"?@@`R4@``(1``,D!0!#$!``O(\!`$,D`@!C
M+$\`8!`E.$``)`"BCRP`HX\``$*,1P!B%%0`OX]0`+Z/3`"WCT@`MH]$`+6/
M0`"TCSP`LX\X`+*/-`"QCS``L(\(`.`#6`"])W[_0!24@)F/`0`0))2`F8\!
M`!`F"?@@`P``1(XE*(`"$`"\CWR!F8\)^"`#)2!``/BQ8HXJ$`("]/]`%!``
MO(]N_P`0E("9CP$`0H`9_T`03("9CQ3_`!``````*(""CU"`F8\4^Q$$]+%$
MC!``O(\E@$``Q_]`%/RQ(JXD@(2/_("9CPGX(`/87X0D"?@@`P`````0`+R/
M$``#CBB`@H\D@)F/``!DC/2Q0HS0-#DGCO<1!```18R0_P`0$`"\CY2`F8\)
M^"`#``!$CA``O(\E($``$``#CMB`F8\)^"`#``!EC&/_`!`0`+R/:(&9CPGX
M(`,`````*(""CR2`A(\E,``"_("9C_2Q0HS\7X0D"?@@`P``18P"`!P\-,F<
M)R'@F0/8_[TG5("9CQ``O*\@`+&O)8B``"0`OZ_[^!$$'`"PKP``1(`=`(`0
M$`"\CP$`0R0E@$``+P"".```9(`*@&(`_/^`%`$`8R1(@)F/#OH1!``````,
M`$`0$`"\CPL`(!(D`+^/```B@@@`0!`E(``")("%CZB!F8\)^"`#Q%ZE)`@`
M`A(0`+R/)`"_CR``L8\<`+"/"`#@`R@`O2?J_P`0)8!``"2`F8\E("`")`"_
MCR``L8\<`+"/V#$Y)X3V`!`H`+TG``````(`'#Q@R)PG(>"9`VB`@H\#`$`0
M0(&9CP@`(`,``$>,"``@`R4X``````````````(`'#PPR)PG(>"9`\C_O2=L
M@)F/$`"\KS``M:\EJ,``+`"TKR6@H``H`+.O)9B``"0`LJ\<`+"O-`"_KQGO
M$00@`+&O$`"\CW"`D(]T@)*/(Y!0`H.0$@`)`$`2)8@`````&8X!`#$F)3"@
M`B4H@`()^"`#)2!@`OG_418$`!`F-`"_CS``M8\L`+2/*`"SCR0`LH\@`+&/
M'`"PCP@`X`,X`+TG"`#@`P``````````$("9CR5XX`,)^"`#;0`8)!"`F8\E
M>.`#"?@@`VP`&"00@)F/)7C@`PGX(`-J`!@D$("9CR5XX`,)^"`#:``8)!"`
MF8\E>.`#"?@@`V8`&"00@)F/)7C@`PGX(`-E`!@D$("9CR5XX`,)^"`#9``8
M)!"`F8\E>.`#"?@@`V(`&"00@)F/)7C@`PGX(`-@`!@D$("9CR5XX`,)^"`#
M7P`8)!"`F8\E>.`#"?@@`UX`&"00@)F/)7C@`PGX(`-=`!@D$("9CR5XX`,)
M^"`#7``8)!"`F8\E>.`#"?@@`UH`&"00@)F/)7C@`PGX(`-9`!@D$("9CR5X
MX`,)^"`#5P`8)!"`F8\E>.`#"?@@`U8`&"00@)F/)7C@`PGX(`-5`!@D$("9
MCR5XX`,)^"`#5``8)!"`F8\E>.`#"?@@`U,`&"00@)F/)7C@`PGX(`-2`!@D
M$("9CR5XX`,)^"`#40`8)!"`F8\E>.`#"?@@`U``&"00@)F/)7C@`PGX(`-/
M`!@D$("9CR5XX`,)^"`#3@`8)!"`F8\E>.`#"?@@`TT`&"00@)F/)7C@`PGX
M(`-,`!@D$("9CR5XX`,)^"`#2@`8)!"`F8\E>.`#"?@@`T@`&"00@)F/)7C@
M`PGX(`-'`!@D$("9CR5XX`,)^"`#1@`8)!"`F8\E>.`#"?@@`T4`&"00@)F/
M)7C@`PGX(`-$`!@D$("9CR5XX`,)^"`#0P`8)!"`F8\E>.`#"?@@`T(`&"00
M@)F/)7C@`PGX(`-!`!@D$("9CR5XX`,)^"`#0``8)!"`F8\E>.`#"?@@`S\`
M&"00@)F/)7C@`PGX(`,^`!@D$("9CR5XX`,)^"`#/``8)!"`F8\E>.`#"?@@
M`SL`&"00@)F/)7C@`PGX(`,Z`!@D$("9CR5XX`,)^"`#.0`8)!"`F8\E>.`#
M"?@@`S@`&"00@)F/)7C@`PGX(`,W`!@D$("9CR5XX`,)^"`#-@`8)!"`F8\E
M>.`#"?@@`S4`&"00@)F/)7C@`PGX(`,T`!@D$("9CR5XX`,)^"`#,P`8)!"`
MF8\E>.`#"?@@`S``&"00@)F/)7C@`PGX(`,O`!@D$("9CR5XX`,)^"`#+@`8
M)!"`F8\E>.`#"?@@`RT`&"00@)F/)7C@`PGX(`,K`!@D$("9CR5XX`,)^"`#
M*0`8)!"`F8\E>.`#"?@@`R@`&"00@)F/)7C@`PGX(`,G`!@D$("9CR5XX`,)
M^"`#)@`8)!"`F8\E>.`#"?@@`R4`&"00@)F/)7C@`PGX(`,D`!@D$("9CR5X
MX`,)^"`#(P`8)``````````````````````"`!P\H,.<)R'@F0/@_[TG$`"\
MKQP`OZ\<`+^/"`#@`R``O2<````````````````!``(`)7,O)7,````O<')O
M8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%
M35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"
M54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````
M3$E"4$%42`!,1%],24)205)97U!!5$@`3$E"4D%265]0051(`````$193$1?
M3$E"4D%265]0051(````4TA,24)?4$%42```55-%4@````!365-414T``"]T
M;7``````5$5-4$1)4@!435``55-%4DY!344`````)3`R>``````E<R5S)7,E
M<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,`````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M05)'5@`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`
M````,2XP,S4```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.
M5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?
M)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!
M4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@
M)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI
M;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*
M<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O
M;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U
M9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B
M.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X
M*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O
M9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S
M970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@
M)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL
M96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H
M;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D
M97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U
M="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP
M<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME
M>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S
M("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U
M<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U
M9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[
M8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@
M)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@
M)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D
M;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE
M;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD
M<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@
M+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB
M.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H
M)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\[
M"F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)
M3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M
M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F
M:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B
M8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B
M('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L
M<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM
M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C
M:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@
M*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G
M;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS
M965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E
M860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*
M96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B
M*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H
M)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO
M<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT
M+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@
M/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP
M9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL
M96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@
M)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N
M)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E
M>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%
M3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS
M:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L
M=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI
M.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````````````````!?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$P9
M``#@&`````````````````````````````#_____````````````````2&``
M````````````````````````````````````````````````@.`4````6```
MI%@```````````(````!``PV``#(40``Z#8``)1```!`0```%#@``)`_``"0
M/```G$(``!`[``#05P``(*`!`/Q6```TH`$`W*$!`*04``#TGP$`^)\!````
M````````<%P``&!<``!07```0%P``#!<```@7```$%P`````````7```````
M`/!;``#@6P``T%L``,!;`````````````+!;``"@6P``D%L``(!;``!P6P``
M8%L``%!;``!`6P``,%L``"!;````````$%L```!;``#P6@``X%H``-!:``#`
M6@``L%H``*!:``"06@``@%H``'!:````````8%H```````!06@``0%H``#!:
M```@6@``$%H```!:``#P60``X%D``-!9``#`60``L%D``*!9````````D%D`
M`(!9````````<%D``&!9``!060``0%D``#!9````````(%D````````060``
M`%D``/!8````````X%@```````#06````````,!8``"P6```W*$!`$=#0SH@
M*$1E8FEA;B`V+C(N,"TT*2`V+C(N,"`R,#$V,#DQ-`````"P&0`````#@/S_
M__\``````````+`"```=````'P```-0L`````'^`_/___P``````````.```
M`!T````?````'"X`````'X#\____```````````X````'0```!\```#\+@``
M``#_@/S___\``````````$@````=````'P```-@Q`````/^`_/___P``````
M````\````!T````?````_#,``````X#\____```````````H````'0```!\`
M``#0-``````?@/S___\``````````#@0```=````'P````PV``````"`_/__
M_P``````````(````!T````?````8#8``````8#\____```````````H````
M'0```!\```#H-@`````'@/S___\``````````$`@```=````'P```/PW````
M`````````````````````````!T````?````%#@`````_\#\____````````
M``!@$```'0```!\```#D.@`````````````````````````````=````'P``
M`!`[``````.`_/___P``````````*````!T````?````D#P`````_X#\____
M``````````!P````'0```!\```"0/P`````#@/S___\``````````#`````=
M````'P```$!```````"`_/___P``````````(````!T````?````E$``````
M_\#\____``````````"(````'0```!\```"<0@````#_P/S___\`````````
M`'B!```=````'P```,A1`````/_`_/___P``````````6````!T````?````
M_%8``````X#\____```````````H````'0```!\```#@%``````_@/S___\`
M`````````%@````=````'P```-!7`````````````````````````````!T`
M```?`````%@`````/X#\____```````````X````'0```!\```"D6```````
M```````````````````````=````'P```$$/````9VYU``$'````!`4`+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N34E04RYA8FEF;&%G<P`N
M<F5G:6YF;P`N;F]T92YG;G4N8G5I;&0M:60`+F1Y;F%M:6,`+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N:6YI=``N=&5X=``N34E04RYS='5B<P`N9FEN:0`N<F]D871A`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD871A`"YR
M;&1?;6%P`"YG;W0`+G-D871A`"YB<W,`+F-O;6UE;G0`+G!D<@`N9VYU+F%T
M=')I8G5T97,`+FUD96)U9RYA8FDS,@``````````````````````````````
M````````````````````````````"P````$````"````E`$``)0!```-````
M```````````!`````````!,````'`````@```*0!``"D`0``(```````````
M````!``````````A````*@``<`(```#(`0``R`$``!@```````````````@`
M```8````,`````8``'`"````X`$``.`!```8```````````````$````&```
M`#D````'`````@```/@!``#X`0``)```````````````!`````````!,````
M!@````(````<`@``'`(``%`!```)``````````0````(````50````4````"
M````;`,``&P#``!$`P``"``````````$````!````%L````+`````@```+`&
M``"P!@``X`8```D````"````!````!````!C`````P````(```"0#0``D`T`
M`&`%``````````````$`````````:P```/___V\"````\!(``/`2``#<````
M"``````````"`````@```'@```#^__]O`@```,P3``#,$P``L`````D````#
M````!`````````"'````"0````(```!\%```?!0``"@````(``````````0`
M```(````D`````$````&````I!0``*04```\```````````````$````````
M`)8````!````!@```.`4``#@%```T$,`````````````$`````````"<````
M`0````8```"P6```L%@``.`#``````````````0`````````J`````$````&
M````D%P``)!<```D```````````````$`````````*X````!`````@```,!<
M``#`7```0$$`````````````$`````````"V`````0````(`````G@```)X`
M``0```````````````0`````````P`````X````#````])\!`/2?```$````
M```````````$````!````,P````/`````P```/B?`0#XGP``!```````````
M````!`````0```#8`````0````,```#\GP$`_)\```0```````````````0`
M````````W0````$````#`````*`!``"@```P```````````````0````````
M`.,````!`````P```#"@`0`PH```!```````````````!`````````#L````
M`0````,``!!`H`$`0*```)P!`````````````!`````$````\0````$````#
M```0W*$!`-RA```$```````````````$`````````/@````(`````P```."A
M`0#@H0``,!``````````````$`````````#]`````0```#``````````X*$`
M`"4```````````````$````!````!@$```$```````````````BB```@`P``
M```````````$``````````L!``#U__]O```````````HI0``$```````````
M`````0`````````;`0```0``````````````.*4```````````````````$`
M`````````0````,``````````````#BE```I`0`````````````!````````
!````
